#!/usr/bin/python

# debgtd - debian BTS helper tool for users
# Copyright (c) 2008, Jon Dowland <jon@alcopop.org>

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# see "LICENSE" for the full GPL-2.

import sys

from debgtd.controller import Controller
from debgtd.gui import Gui

if __name__ == "__main__":
	controller = Controller()
	gui = Gui(controller)
	controller.add_view(gui)
	try:
		try:
			controller.go()
		except KeyboardInterrupt:
			sys.exit(1)
	finally:
		controller.save_to_file()
